# Generated by roxygen2: do not edit by hand

S3method(future,starburst)
S3method(launchFuture,StarburstBackend)
S3method(listFutures,StarburstBackend)
S3method(nbrOfWorkers,StarburstBackend)
S3method(plan,starburst)
S3method(print,StarburstSessionStatus)
S3method(resolved,StarburstFuture)
S3method(result,StarburstFuture)
S3method(run,StarburstFuture)
export(StarburstBackend)
export(StarburstFuture)
export(starburst)
export(starburst_check_quota_request)
export(starburst_cleanup_ecr)
export(starburst_cluster)
export(starburst_config)
export(starburst_estimate)
export(starburst_is_configured)
export(starburst_list_sessions)
export(starburst_logs)
export(starburst_map)
export(starburst_quota_status)
export(starburst_rebuild_environment)
export(starburst_request_quota_increase)
export(starburst_session)
export(starburst_session_attach)
export(starburst_setup)
export(starburst_setup_ec2)
export(starburst_status)
importFrom(future,future)
importFrom(future,launchFuture)
importFrom(future,listFutures)
importFrom(future,nbrOfWorkers)
importFrom(future,plan)
importFrom(future,resolved)
importFrom(future,result)
importFrom(future,run)
importFrom(stats,runif)
importFrom(utils,capture.output)
