# Logo Files

This directory contains the staRburst logo and other figures.

## Logo

Please save the staRburst logo image as `logo.png` in this directory.

The logo should be the sticker-style image with:
- "staRburst" branding
- "Bursting R Code to the Cloud!" tagline
- Rocket and explosion graphics
- Orange/blue color scheme

The README.md references this logo at `man/figures/logo.png`.
