#' @keywords internal
#' @importFrom stats runif
#' @importFrom utils capture.output
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL

# Package-level environment for internal state
.starburst_env <- new.env(parent = emptyenv())
