% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-backend.R
\name{initialize_detached_backend}
\alias{initialize_detached_backend}
\title{Initialize backend for detached mode}
\usage{
initialize_detached_backend(
  session_id,
  workers = 10,
  cpu = 4,
  memory = "8GB",
  region = NULL,
  timeout = 3600,
  absolute_timeout = 86400,
  launch_type = "EC2",
  instance_type = "c7g.xlarge",
  use_spot = TRUE,
  warm_pool_timeout = 3600
)
}
\arguments{
\item{session_id}{Unique session identifier}

\item{workers}{Number of workers}

\item{cpu}{vCPUs per worker}

\item{memory}{Memory per worker (GB notation like "8GB")}

\item{region}{AWS region}

\item{timeout}{Task timeout in seconds}

\item{absolute_timeout}{Maximum session lifetime in seconds}

\item{launch_type}{"FARGATE" or "EC2"}

\item{instance_type}{EC2 instance type (for EC2 launch type)}

\item{use_spot}{Use spot instances}

\item{warm_pool_timeout}{Warm pool timeout for EC2}
}
\value{
Backend environment
}
\description{
Creates a backend for detached sessions without modifying the future plan
}
\keyword{internal}
