% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{poll_for_result}
\alias{poll_for_result}
\title{Poll for result}
\usage{
poll_for_result(future, timeout = 3600)
}
\description{
Poll for result
}
\keyword{internal}
