% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{starburst_is_configured}
\alias{starburst_is_configured}
\title{Check if staRburst is configured}
\usage{
starburst_is_configured()
}
\value{
\code{TRUE} if configured and credentials are available, \code{FALSE} otherwise.
}
\description{
Returns \code{TRUE} if \code{starburst_setup()} has been run, the
configuration file exists, and AWS credentials are available.
Useful for guarding example code that requires AWS credentials.
}
\examples{
starburst_is_configured()
}
