% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/future-starburst.R
\name{StarburstFuture}
\alias{StarburstFuture}
\title{StarburstFuture Constructor}
\usage{
StarburstFuture(
  expr,
  envir = parent.frame(),
  substitute = TRUE,
  globals = TRUE,
  packages = NULL,
  lazy = FALSE,
  seed = FALSE,
  stdout = TRUE,
  conditions = "condition",
  label = NULL,
  ...
)
}
\arguments{
\item{expr}{Expression to evaluate}

\item{envir}{Environment for evaluation}

\item{substitute}{Whether to substitute the expression}

\item{globals}{Globals to export (TRUE for auto-detection, list for manual)}

\item{packages}{Packages to load}

\item{lazy}{Whether to lazily evaluate (always FALSE for remote)}

\item{seed}{Random seed}

\item{...}{Additional arguments}
}
\value{
A StarburstFuture object
}
\description{
Creates a Future object for evaluation on AWS workers (EC2 by default, or Fargate)
}
\keyword{internal}
