% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quota.R
\name{load_quota_history}
\alias{load_quota_history}
\title{Load quota request history}
\usage{
load_quota_history()
}
\description{
Load quota request history
}
\keyword{internal}
