% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/task-registry.R
\name{get_task_arn}
\alias{get_task_arn}
\title{Get task ARN}
\usage{
get_task_arn(task_id)
}
\description{
Get task ARN
}
\keyword{internal}
