% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cost.R
\name{calculate_total_cost}
\alias{calculate_total_cost}
\title{Calculate total cost}
\usage{
calculate_total_cost(plan)
}
\description{
Calculate total cost
}
\keyword{internal}
