% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{result_exists}
\alias{result_exists}
\title{Check if result exists}
\usage{
result_exists(task_id, region)
}
\description{
Check if result exists
}
\keyword{internal}
