% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{config_dir}
\alias{config_dir}
\title{Get configuration directory}
\usage{
config_dir()
}
\description{
Get configuration directory
}
\keyword{internal}
