% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{extract_region_from_key}
\alias{extract_region_from_key}
\title{Extract region from S3 key}
\usage{
extract_region_from_key(key)
}
\description{
Extract region from S3 key
}
\keyword{internal}
