% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{get_starburst_bucket}
\alias{get_starburst_bucket}
\title{Get starburst bucket name}
\usage{
get_starburst_bucket()
}
\value{
S3 bucket name
}
\description{
Get starburst bucket name
}
\keyword{internal}
