% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{save_config}
\alias{save_config}
\title{Save staRburst configuration}
\usage{
save_config(config)
}
\description{
Save staRburst configuration
}
\keyword{internal}
