% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{session-state}
\alias{session-state}
\title{S3 Session State Management}
\description{
Core S3 operations for managing detached session state
}
\keyword{internal}
