% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{create_ecs_cluster}
\alias{create_ecs_cluster}
\title{Create ECS cluster}
\usage{
create_ecs_cluster(cluster_name, region)
}
\description{
Create ECS cluster
}
\keyword{internal}
