% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/starburst-estimate.R
\name{get_local_hardware_specs}
\alias{get_local_hardware_specs}
\title{Get Local Hardware Specifications}
\usage{
get_local_hardware_specs()
}
\value{
List with cpu_name, cores, and architecture
}
\description{
Detects local CPU model and core count for performance estimation.
}
\keyword{internal}
