% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-api.R
\name{session-api}
\alias{session-api}
\title{Detached Session API}
\description{
User-facing API for creating and managing detached sessions
}
