% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cost.R
\name{calculate_task_cost}
\alias{calculate_task_cost}
\title{Calculate task cost}
\usage{
calculate_task_cost(future)
}
\description{
Calculate task cost
}
\keyword{internal}
