% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plan-starburst.R
\name{register_cleanup}
\alias{register_cleanup}
\title{Register cleanup handler}
\usage{
register_cleanup(evaluator)
}
\description{
Register cleanup handler
}
\keyword{internal}
