% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aws-clients.R
\name{get_s3_client}
\alias{get_s3_client}
\title{Get S3 client}
\usage{
get_s3_client(region)
}
\arguments{
\item{region}{AWS region}
}
\value{
S3 client
}
\description{
Get S3 client
}
\keyword{internal}
