% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/images.R
\name{compute_env_hash}
\alias{compute_env_hash}
\title{Compute environment image hash}
\usage{
compute_env_hash(lock_file)
}
\arguments{
\item{lock_file}{Path to renv.lock file}
}
\value{
MD5 hash string
}
\description{
Computes the hash used to tag environment Docker images, combining the
renv.lock file contents with the starburst package version. This ensures
new images are built when either the R package environment or the starburst
worker script changes.
}
\keyword{internal}
