% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{safe_system}
\alias{safe_system}
\title{Execute system command safely (no shell injection)}
\usage{
safe_system(
  command,
  args = character(),
  allowed_commands = c("docker", "aws", "uname", "sysctl", "cat", "nproc"),
  stdin = NULL,
  stdout = "|",
  stderr = "|",
  ...
)
}
\arguments{
\item{command}{Command to execute (must be in whitelist)}

\item{args}{Character vector of arguments}

\item{allowed_commands}{Commands allowed to be executed}

\item{stdin}{Optional input to pass to stdin}

\item{...}{Additional arguments passed to processx::run()}
}
\value{
Result from processx::run()
}
\description{
Execute system command safely (no shell injection)
}
\keyword{internal}
