% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{config_path}
\alias{config_path}
\title{Get configuration file path}
\usage{
config_path()
}
\description{
Get configuration file path
}
\keyword{internal}
