% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quota.R
\name{get_current_vcpu_usage}
\alias{get_current_vcpu_usage}
\title{Get current vCPU usage}
\usage{
get_current_vcpu_usage(region)
}
\description{
Get current vCPU usage
}
\keyword{internal}
