% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-api.R
\name{starburst_list_sessions}
\alias{starburst_list_sessions}
\title{List All Sessions}
\usage{
starburst_list_sessions(region = NULL)
}
\arguments{
\item{region}{AWS region (default: from config)}
}
\value{
Data frame with session information
}
\description{
List all detached sessions in S3
}
\examples{
\donttest{
if (starburst_is_configured()) {
  sessions <- starburst_list_sessions()
  print(sessions)
}
}
}
