% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{setup_vpc_resources}
\alias{setup_vpc_resources}
\title{Setup VPC resources}
\usage{
setup_vpc_resources(region)
}
\description{
Setup VPC resources
}
\keyword{internal}
