% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{is_setup_complete}
\alias{is_setup_complete}
\title{Check if setup is complete}
\usage{
is_setup_complete()
}
\description{
Check if setup is complete
}
\keyword{internal}
