% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/task-registry.R
\name{list_active_clusters}
\alias{list_active_clusters}
\title{List active clusters}
\usage{
list_active_clusters(region)
}
\description{
List active clusters
}
\keyword{internal}
