% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/images.R
\name{get_base_image_uri}
\alias{get_base_image_uri}
\title{Get base image URI}
\usage{
get_base_image_uri(region)
}
\description{
Get base image URI
}
\keyword{internal}
