% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-api.R
\name{get_session_status}
\alias{get_session_status}
\title{Get session status}
\usage{
get_session_status(session)
}
\description{
Get session status
}
\keyword{internal}
