% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/task-definition.R
\name{ensure_log_group}
\alias{ensure_log_group}
\title{Ensure CloudWatch log group exists}
\usage{
ensure_log_group(log_group_name, region)
}
\description{
Ensure CloudWatch log group exists
}
\keyword{internal}
