% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/images.R
\name{ensure_environment}
\alias{ensure_environment}
\title{Ensure environment is ready}
\usage{
ensure_environment(region)
}
\description{
Ensure environment is ready
}
\keyword{internal}
