% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-api.R
\name{print.StarburstSessionStatus}
\alias{print.StarburstSessionStatus}
\title{Print method for session status}
\usage{
\method{print}{StarburstSessionStatus}(x, ...)
}
\arguments{
\item{x}{A StarburstSessionStatus object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print method for session status
}
