% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/task-registry.R
\name{store_task_arn}
\alias{store_task_arn}
\title{Store task ARN}
\usage{
store_task_arn(task_id, task_arn)
}
\description{
Store task ARN
}
\keyword{internal}
