% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-api.R
\name{extend_session_timeout}
\alias{extend_session_timeout}
\title{Extend session timeout}
\usage{
extend_session_timeout(session, seconds)
}
\description{
Extend session timeout
}
\keyword{internal}
