% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{cleanup_s3_files}
\alias{cleanup_s3_files}
\title{Cleanup S3 files}
\usage{
cleanup_s3_files(plan)
}
\description{
Cleanup S3 files
}
\keyword{internal}
