% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plan-starburst.R
\name{cleanup_cluster}
\alias{cleanup_cluster}
\title{Clean up cluster resources}
\usage{
cleanup_cluster(backend)
}
\description{
Clean up cluster resources
}
\keyword{internal}
