% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{s3-io}
\alias{s3-io}
\title{S3 task/result I/O for staRburst}
\description{
Serialization of task payloads to S3, polling for results, and cleanup of
the per-cluster task objects.
}
\keyword{internal}
