% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{list_task_statuses}
\alias{list_task_statuses}
\title{List all task statuses in session}
\usage{
list_task_statuses(session_id, region, bucket)
}
\arguments{
\item{session_id}{Session identifier}

\item{region}{AWS region}

\item{bucket}{S3 bucket}
}
\value{
Named list of task statuses (task_id -> status)
}
\description{
List all task statuses in session
}
\keyword{internal}
