% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ec2-pool.R
\name{ec2-pool}
\alias{ec2-pool}
\title{EC2 Pool Management for staRburst}
\description{
Functions for managing Auto-Scaling Groups and ECS Capacity Providers
to maintain warm pools of EC2 instances for fast task execution.
}
\keyword{internal}
