% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{create_task}
\alias{create_task}
\title{Create task object}
\usage{
create_task(expr, globals, packages, plan)
}
\description{
Create task object
}
\keyword{internal}
