% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/starburst-estimate.R
\name{get_cloud_performance_ratio}
\alias{get_cloud_performance_ratio}
\title{Get Cloud Performance Ratio}
\usage{
get_cloud_performance_ratio(local_specs, platform)
}
\description{
Returns estimated per-core performance of cloud vs local hardware.
Based on empirical benchmarking data.
}
\keyword{internal}
