% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/logs.R
\name{starburst_logs}
\alias{starburst_logs}
\title{View worker logs}
\usage{
starburst_logs(task_id = NULL, cluster_id = NULL, last_n = 50, region = NULL)
}
\arguments{
\item{task_id}{Optional task ID to view logs for specific task}

\item{cluster_id}{Optional cluster ID to view logs for specific cluster}

\item{last_n}{Number of last log lines to show (default: 50)}

\item{region}{AWS region (default: from config)}
}
\value{
Invisibly returns the list of log events, or \code{NULL} if no
  events were found.
}
\description{
View worker logs
}
\examples{
\donttest{
if (starburst_is_configured()) {
  # View recent logs
  starburst_logs()

  # View logs for specific task
  starburst_logs(task_id = "abc-123")

  # View last 100 lines
  starburst_logs(last_n = 100)
}
}
}
