% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{create_task_status}
\alias{create_task_status}
\title{Create task status in S3}
\usage{
create_task_status(session_id, task_id, state = "pending", region, bucket)
}
\arguments{
\item{session_id}{Session identifier}

\item{task_id}{Task identifier}

\item{state}{Initial state (default: "pending")}

\item{region}{AWS region}

\item{bucket}{S3 bucket}
}
\value{
Invisibly returns NULL
}
\description{
Create task status in S3
}
\keyword{internal}
