% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-io.R
\name{serialize_and_upload}
\alias{serialize_and_upload}
\title{Serialize and upload to S3}
\usage{
serialize_and_upload(obj, bucket, key)
}
\description{
Serialize and upload to S3
}
\keyword{internal}
