% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/images.R
\name{build_initial_environment}
\alias{build_initial_environment}
\title{Build initial environment}
\usage{
build_initial_environment(region)
}
\description{
Build initial environment
}
\keyword{internal}
