% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{create_ecr_repository}
\alias{create_ecr_repository}
\title{Create ECR repository}
\usage{
create_ecr_repository(repo_name, region)
}
\description{
Create ECR repository
}
\keyword{internal}
