% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plan-starburst.R
\name{get_wave_status}
\alias{get_wave_status}
\title{Get wave queue status}
\usage{
get_wave_status(backend)
}
\arguments{
\item{backend}{Backend environment}
}
\description{
Get wave queue status
}
\keyword{internal}
