% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ec2-pool.R
\name{start_warm_pool}
\alias{start_warm_pool}
\title{Start warm EC2 pool}
\usage{
start_warm_pool(backend, capacity, timeout_seconds = 180)
}
\arguments{
\item{backend}{Backend configuration object}

\item{capacity}{Desired number of instances}

\item{timeout_seconds}{Maximum time to wait for instances (default: 180)}
}
\value{
Invisible NULL
}
\description{
Scales Auto-Scaling Group to desired capacity and waits for instances
}
\keyword{internal}
