% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{create_session_manifest}
\alias{create_session_manifest}
\title{Create session manifest in S3}
\usage{
create_session_manifest(session_id, backend)
}
\arguments{
\item{session_id}{Unique session identifier}

\item{backend}{Backend configuration}
}
\value{
Invisibly returns NULL
}
\description{
Create session manifest in S3
}
\keyword{internal}
