% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/errors.R
\name{starburst_error}
\alias{starburst_error}
\title{Create informative staRburst error}
\usage{
starburst_error(
  message,
  context = list(),
  solution = NULL,
  call = sys.call(-1)
)
}
\arguments{
\item{message}{Main error message}

\item{context}{Named list of contextual information}

\item{solution}{Suggested solution (optional)}

\item{call}{Calling function (default: sys.call(-1))}
}
\value{
Error condition with class "starburst_error"
}
\description{
Creates error messages with context, solutions, and links to documentation
}
\keyword{internal}
