% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quota.R
\name{starburst_quota_status}
\alias{starburst_quota_status}
\title{Show quota status}
\usage{
starburst_quota_status(region = NULL)
}
\arguments{
\item{region}{AWS region (default: from config)}
}
\value{
Invisibly returns a list with quota information including current
  limit, usage, and any pending requests.
}
\description{
Show quota status
}
\examples{
\donttest{
if (starburst_is_configured()) {
  starburst_quota_status()
}
}
}
