% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/errors.R
\name{errors}
\alias{errors}
\title{Error Handling for staRburst}
\description{
Improved error messages with context and solutions
}
\keyword{internal}
