% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{get_task_status}
\alias{get_task_status}
\title{Get task status from S3}
\usage{
get_task_status(session_id, task_id, region, bucket, include_etag = FALSE)
}
\arguments{
\item{session_id}{Session identifier}

\item{task_id}{Task identifier}

\item{region}{AWS region}

\item{bucket}{S3 bucket}

\item{include_etag}{Include ETag in result (for atomic operations)}
}
\value{
Task status list (with optional $etag field)
}
\description{
Get task status from S3
}
\keyword{internal}
