% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aws-clients.R
\name{get_aws_account_id}
\alias{get_aws_account_id}
\title{Get AWS account ID}
\usage{
get_aws_account_id()
}
\value{
AWS account ID
}
\description{
Get AWS account ID
}
\keyword{internal}
