% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cost.R
\name{cost}
\alias{cost}
\title{Cost estimation and pricing for staRburst}
\description{
Cost estimation and pricing for staRburst
}
\keyword{internal}
