% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-state.R
\name{atomic_claim_task}
\alias{atomic_claim_task}
\title{Atomically claim a pending task}
\usage{
atomic_claim_task(session_id, task_id, worker_id, region, bucket)
}
\arguments{
\item{session_id}{Session identifier}

\item{task_id}{Task identifier}

\item{worker_id}{Worker identifier claiming the task}

\item{region}{AWS region}

\item{bucket}{S3 bucket}
}
\value{
TRUE if claimed successfully, FALSE if already claimed
}
\description{
This is a helper that combines get + conditional update in one operation
}
\keyword{internal}
