% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/task-registry.R
\name{stop_running_tasks}
\alias{stop_running_tasks}
\title{Stop running tasks}
\usage{
stop_running_tasks(plan)
}
\description{
Stop running tasks
}
\keyword{internal}
