% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/network.R
\name{get_vpc_config}
\alias{get_vpc_config}
\title{Get VPC configuration for ECS tasks}
\usage{
get_vpc_config(region)
}
\description{
Get VPC configuration for ECS tasks
}
\keyword{internal}
