% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-backend.R
\name{session-backend}
\alias{session-backend}
\title{Session Backend Initialization}
\description{
Backend initialization for detached session mode
}
\keyword{internal}
